# iOS bindings

The Glean SDK contains the Swift bindings for use by iOS applications.
It makes use of the underlying [Rust component](../core/index.md) with a Swift-specific API on top.
It also includes integrations into the iOS platform.
